@@ -15,12 +15,12 @@ with a strong **Component** Architecture.
 """
 
 __author__ = "James Mills"
-__date__ = "22nd November 2012"
-__version__ = "2.0.1"
+__date__ = "24th February 2013"
+__version__ = "2.1.0"
 
-from circuits.core import future, Pool, Task, Worker
-from circuits.core import Debugger, Loader, Manager, Timer
-from circuits.core import handler, tick, BaseComponent, Component
+from circuits.core import  Task, Worker
+from circuits.core import Debugger, Bridge, Loader, Manager, Timer
 from circuits.core import BaseEvent, DerivedEvent, Event, LiteralEvent
+from circuits.core import handler, reprhandler, BaseComponent, Component
 
-# hghooks: no-pyflakes
+# flake8: noqa
