@@ -15,17 +15,18 @@ from circuits.core import handler, Event, BaseComponent
 class Log(Event):
     """Log Event"""
 
-    channel = "log"
-    target = "logger"
+    channels = ("logger",)
 
 
 class Logger(BaseComponent):
 
     channel = "logger"
 
-    LEVELS = {"debug": DEBUG, "info": INFO, "warning": WARNING,
-            "warn": WARN, "error": ERROR, "exception": ERROR,
-            "critical": CRITICAL}
+    LEVELS = {
+        "debug": DEBUG, "info": INFO, "warning": WARNING,
+        "warn": WARN, "error": ERROR, "exception": ERROR,
+        "critical": CRITICAL
+    }
 
     def __init__(self, filename, name, type, level, channel=channel):
         super(Logger, self).__init__(channel=channel)
@@ -62,7 +63,7 @@ class Logger(BaseComponent):
         else:
             self.logger.setLevel(logging.WARNING)
 
-        formatter = logging.Formatter(format,dateFormat)
+        formatter = logging.Formatter(format, dateFormat)
         hdlr.setFormatter(formatter)
         self.logger.addHandler(hdlr)
 
