@@ -7,26 +7,25 @@
 This package contains the essential core parts of the circuits framework.
 """
 
-from .handlers import handler, tick
 
+from .bridge import Bridge
 from .loader import Loader
 from .manager import Manager
+from .handlers import handler, reprhandler
 from .components import BaseComponent, Component
 from .events import BaseEvent, DerivedEvent, Event, LiteralEvent
 
 from .values import Value
-from .futures import future
 
 from .timers import Timer
 
-from .pools import Pool
 from .workers import Task, Worker
+
 from .debugger import Debugger
 
-__all__ = ("handler", "BaseComponent", "Component", "Event",
-        "future", "Pool", "Task", "Worker",
-        "Bridge", "Debugger", "Timer",
-        "Manager",
+__all__ = (
+    "handler", "BaseComponent", "Component", "Event", "Map", "Pool", "Task",
+    "Worker", "Bridge", "Debugger", "Timer", "Manager",
 )
 
-# hghooks: no-pyflakes
+# flake8: noqa
