@@ -34,9 +34,17 @@ class Error(Event):
     """Error Event"""
 
 
+class Open(Event):
+    """Open Event"""
+
+
 class Opened(Event):
     """Opened Event"""
 
 
 class Closed(Event):
     """Closed Event"""
+
+
+class Ready(Event):
+    """Ready Event"""
