@@ -12,19 +12,17 @@ from hashlib import md5
 from warnings import warn
 
 
-class Unknown(object):
-    """Unknown Dummy Component"""
+def tryimport(modules, obj=None, message=None):
+    modules = (modules,) if isinstance(modules, str) else modules
 
-
-def tryimport(modules, message=None):
-    if isinstance(modules, str):
-        modules = (modules,)
     for module in modules:
         try:
-            return __import__(module, globals(), locals())
-        except ImportError:
+            m = __import__(module, globals(), locals())
+            return getattr(m, obj) if obj is not None else m
+        except:
             pass
-    if message:
+
+    if message is not None:
         warn(message)
 
 
@@ -101,20 +99,6 @@ def graph(x, name=None):
     return "\n".join(walk(x, printer))
 
 
-def reprhandler(handler):
-    format = "<%s[%s.%s] (%s.%s)>"
-
-    channel = handler.channel or "*"
-    names = ".".join(handler.names)
-    type = "filter" if handler.filter else "listener"
-
-    instance = getattr(handler, "im_self",
-            getattr(handler, "__self__", Unknown())).__class__.__name__
-    method = handler.__name__
-
-    return format % (type, channel, names, instance, method)
-
-
 def inspect(x):
     """Display an inspection report of the Component or Manager x
 
@@ -133,11 +117,7 @@ def inspect(x):
         write("  %s\n" % component)
     write("\n")
 
-    ticks = x.getTicks()
-    write(" Tick Functions: %d\n" % len(ticks))
-    for tick in ticks:
-        write("  %s\n" % tick)
-    write("\n")
+    from circuits import reprhandler
 
     write(" Event Handlers: %d\n" % len(x._handlers.values()))
     for event, handlers in x._handlers.items():
