@@ -4,18 +4,17 @@
 
 """Hyper Text Transfer Protocol
 
-This module implements the Hyper Text Transfer Protocol
+This module implements the server side Hyper Text Transfer Protocol
 or commonly known as HTTP.
 """
 
 
-from io import BytesIO
 try:
     from urllib.parse import unquote
     from urllib.parse import urlparse
 except ImportError:
-    from urllib import unquote
-    from urlparse import urlparse
+    from urllib import unquote  # NOQA
+    from urlparse import urlparse  # NOQA
 
 from circuits.net.sockets import Close, Write
 from circuits.core import handler, BaseComponent, Value
@@ -41,7 +40,18 @@ class HTTP(BaseComponent):
     """HTTP Protocol Component
 
     Implements the HTTP server protocol and parses and processes incoming
-    HTTP messages creating and sending an appropriate response.
+    HTTP messages, creating and sending an appropriate response.
+
+    The component handles :class:`~circuits.net.sockets.Read` events
+    on its channel and collects the associated data until a complete
+    HTTP request has been received. It parses the request's content
+    and puts it in a :class:`~circuits.web.wrappers.Request` object and
+    creates a corresponding :class:`~circuits.web.wrappers.Response`
+    object. Then it emits a :class:`~circuits.web.events.Request`
+    event with these objects as arguments.
+
+    The component defines several handlers that send a response back to
+    the client.
     """
 
     channel = "web"
@@ -59,8 +69,9 @@ class HTTP(BaseComponent):
         if data is not None:
             if data:
                 if response.chunked:
-                    buf = [hex(len(data))[2:], b"\r\n", data, b"\r\n"]
-                    data = b"".join(buf)
+                    data = "{0:s}\r\n{1:s}\r\n".format(
+                        hex(len(data))[2:], data
+                    ).encode(self._encoding)
                 self.fire(Write(response.request.sock, data))
             if response.body and not response.done:
                 try:
@@ -79,9 +90,19 @@ class HTTP(BaseComponent):
 
     @handler("response")
     def _on_response(self, response):
+        """``Response`` Event Handler
+
+        :param response: the ``Response`` object created when the
+            HTTP request was initially received.
+        :type response: :class:`~circuits.web.wrappers.Response`
+
+        This handler builds an HTTP response data stream from
+        the information contained in the *response* object and
+        sends it to the client (firing ``Write`` events).
+        """
         self.fire(
-                Write(response.request.sock,
-                    str(response).encode(HTTP_ENCODING)))
+            Write(response.request.sock, str(response).encode(HTTP_ENCODING))
+        )
 
         if response.stream and response.body:
             try:
@@ -95,8 +116,11 @@ class HTTP(BaseComponent):
             elif isinstance(response.body, unicode):
                 body = response.body.encode(self._encoding)
             else:
-                parts = (s if isinstance(s, bytes) else s.encode(self._encoding) \
-                    for s in response.body if s is not None)
+                parts = (
+                    s
+                    if isinstance(s, bytes) else s.encode(self._encoding)
+                    for s in response.body if s is not None
+                )
                 body = b"".join(parts)
 
             if body:
@@ -139,27 +163,37 @@ class HTTP(BaseComponent):
             if not request.body.tell() == contentLength:
                 return
         else:
-            if data.find(b'\r\n\r\n') == -1:
-                buf = self._buffers.setdefault(sock, [])
-                buf.append(data)
-                if len(buf) > MAX_HEADER_FRAGENTS:
-                    del self._buffers[sock]
-                    raise ValueError("Too many HTTP Headers Fragments.")
-                return
             if sock in self._buffers:
+                # header fragments have been received before
                 self._buffers[sock].append(data)
-                data = ''.join(self._buffers[sock])
+                data = b"".join(self._buffers[sock])
+                if data.find(b'\r\n\r\n') == -1:
+                    # still not all headers received
+                    return
+                # all headers received, use combined data and remove buffer
                 del self._buffers[sock]
+            else:
+                # no pending header fragments for this socket
+                if data.find(b'\r\n\r\n') == -1:
+                    # this first chunk doesn't contain all headers yet, buffer
+                    buf = self._buffers.setdefault(sock, [])
+                    buf.append(data)
+                    if len(buf) > MAX_HEADER_FRAGENTS:
+                        del self._buffers[sock]
+                        raise ValueError("Too many HTTP Headers Fragments.")
+                    return
 
             requestline, data = data.split(b"\r\n", 1)
             requestline = requestline.strip().decode(
-                    HTTP_ENCODING, "replace")
+                HTTP_ENCODING, "replace"
+            )
             method, path, protocol = requestline.split(" ", 2)
             scheme, location, path, params, qs, frag = urlparse(path)
 
             protocol = tuple(map(int, protocol[5:].split(".")))
-            request = wrappers.Request(sock, method, scheme, path,
-                    protocol, qs)
+            request = wrappers.Request(
+                sock, method, scheme, path, protocol, qs
+            )
             response = wrappers.Response(request, encoding=self._encoding)
             self._clients[sock] = request, response
 
@@ -199,7 +233,8 @@ class HTTP(BaseComponent):
             end_of_headers = data.find(b"\r\n\r\n")
             if end_of_headers > -1:
                 header_data = data[:end_of_headers].decode(
-                        HTTP_ENCODING, "replace")
+                    HTTP_ENCODING, "replace"
+                )
                 headers = request.headers = parse_headers(header_data)
             else:
                 headers = request.headers = Headers([])
@@ -207,8 +242,13 @@ class HTTP(BaseComponent):
             request.body.write(data[(end_of_headers + 4):])
 
             if headers.get("Expect", "") == "100-continue":
-                return self.fire(Response(wrappers.Response(request, code=100,
-                    encoding=self._encoding)))
+                return self.fire(
+                    Response(
+                        wrappers.Response(
+                            request, code=100, encoding=self._encoding
+                        )
+                    )
+                )
 
             contentLength = int(headers.get("Content-Length", "0"))
             if request.body.tell() < contentLength:
@@ -241,28 +281,35 @@ class HTTP(BaseComponent):
     def _on_httperror(self, event, request, response, code, **kwargs):
         """Default HTTP Error Handler
 
-        Default Error Handler that by default just responds with the response
-        in the error object passed. The response is normally modified by a
-        HTTPError instance or a subclass thereof.
+        Default Error Handler that by default just fires a ``Response``
+        event with the *response* as argument. The *response* is normally
+        modified by a :class:`~circuits.web.errors.HTTPError` instance
+        or a subclass thereof.
         """
-
         response.body = str(event)
         self.fire(Response(response))
 
-    @handler("request_value_changed")
-    def _on_request_value_changed(self, value):
-        if value.handled:
-            return
-        request, response = value.event.args[:2]
-        if value.result and not value.errors:
-            response.body = value.value
-            self.fire(Response(response))
-        else:
-            # This possibly never occurs.
-            self.fire(HTTPError(request, response, error=value.value))
-
     @handler("request_success")
     def _on_request_success(self, e, value):
+        """
+        Handler for the ``RequestSuccess`` event that is automatically
+        generated after all handlers for a
+        :class:`~circuits.web.events.Request` event have been invoked
+        successfully.
+
+        :param e: the successfully handled ``Request`` event (having
+            as attributes the associated
+            :class:`~circuits.web.wrappers.Request` and
+            :class:`~circuits.web.wrappers.Response` objects).
+        :param value: the value(s) returned by the invoked handler(s).
+
+        This handler converts the value(s) returned by the
+        (successfully invoked) handlers for the initial ``Request``
+        event to a body and assigns it to the ``Response`` object's
+        ``body`` attribute. It then fires a
+        :class:`~circuits.web.events.Response` event with the
+        ``Response`` object as argument.
+        """
         # We only want the non-recursive value at this point.
         # If the value is an instance of Value we will set
         # the .notify flag and be notified of changes to the value.
@@ -288,15 +335,25 @@ class HTTP(BaseComponent):
                 error = value.value
                 etype, evalue, traceback = error
                 if isinstance(evalue, RedirectException):
-                    self.fire(Redirect(request, response,
-                        evalue.urls, evalue.status))
+                    self.fire(
+                        Redirect(request, response, evalue.urls, evalue.status)
+                    )
                 elif isinstance(evalue, HTTPException):
                     if evalue.traceback:
-                        self.fire(HTTPError(request, response, evalue.code,
-                            description=evalue.description, error=error))
+                        self.fire(
+                            HTTPError(
+                                request, response, evalue.code,
+                                description=evalue.description,
+                                error=error
+                            )
+                        )
                     else:
-                        self.fire(HTTPError(request, response, evalue.code,
-                            description=evalue.description))
+                        self.fire(
+                            HTTPError(
+                                request, response, evalue.code,
+                                description=evalue.description
+                            )
+                        )
                 else:
                     self.fire(HTTPError(request, response, error=error))
             else:
@@ -308,15 +365,25 @@ class HTTP(BaseComponent):
             etype, evalue, traceback = error = value
 
             if isinstance(evalue, RedirectException):
-                self.fire(Redirect(request, response,
-                    evalue.urls, evalue.status))
+                self.fire(
+                    Redirect(request, response, evalue.urls, evalue.status)
+                )
             elif isinstance(evalue, HTTPException):
                 if evalue.traceback:
-                    self.fire(HTTPError(request, response, evalue.code,
-                        description=evalue.description, error=error))
+                    self.fire(
+                        HTTPError(
+                            request, response, evalue.code,
+                            description=evalue.description,
+                            error=error
+                        )
+                    )
                 else:
-                    self.fire(HTTPError(request, response, evalue.code,
-                        description=evalue.description))
+                    self.fire(
+                        HTTPError(
+                            request, response, evalue.code,
+                            description=evalue.description
+                        )
+                    )
             else:
                 self.fire(HTTPError(request, response, error=error))
         elif type(value) is not bool:
@@ -342,14 +409,24 @@ class HTTP(BaseComponent):
         etype, evalue, traceback = err
 
         if isinstance(evalue, RedirectException):
-            self.fire(Redirect(request, response,
-                evalue.urls, evalue.status))
+            self.fire(
+                Redirect(request, response, evalue.urls, evalue.status)
+            )
         elif isinstance(evalue, HTTPException):
             if evalue.traceback:
-                self.fire(HTTPError(request, response, evalue.code,
-                    description=evalue.description, error=err))
+                self.fire(
+                    HTTPError(
+                        request, response, evalue.code,
+                        description=evalue.description,
+                        error=err
+                    )
+                )
             else:
-                self.fire(HTTPError(request, response, evalue.code,
-                    description=evalue.description))
+                self.fire(
+                    HTTPError(
+                        request, response, evalue.code,
+                        description=evalue.description
+                    )
+                )
         else:
             self.fire(HTTPError(request, response, error=err))
