@@ -13,6 +13,7 @@ from collections import defaultdict
 
 from circuits import handler, Component
 
+
 class Sessions(Component):
 
     channel = "web"
@@ -29,7 +30,7 @@ class Sessions(Component):
     def _save(self, id, data):
         self._data[id] = data
 
-    @handler("request", filter=True, priority=10)
+    @handler("request", priority=10)
     def request(self, request, response):
         if self._name in request.cookie:
             id = request.cookie[self._name].value
