@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 
-from circuits import Debugger
 from circuits.web import Server, Controller
 
+
 class Root(Controller):
 
     def index(self):
         return "Hello World!"
 
-(Server(("localhost", 8000), ssl=True, certfile="cert.pem") + Debugger() + Root()).run()
\ No newline at end of file
+
+(Server(("localhost", 8000), secure=True, certfile="cert.pem") + Root()).run()
