@@ -3,14 +3,15 @@
 from circuits import Component
 from circuits.web.dispatchers import WebSockets
 from circuits.web import Server, Controller, Logger
+from circuits.net.sockets import Write
 
 
 class Echo(Component):
 
     channel = "ws"
 
-    def message(self, sock, data):
-        return data
+    def read(self, sock, data):
+        self.fireEvent(Write(sock, "Received: " + data))
 
 
 class Root(Controller):
