@@ -3,11 +3,16 @@
 import os
 import sys
 
-from coverage import coverage
+try:
+    from coverage import coverage
+    HAS_COVERAGE = True
+except ImportError:
+    HAS_COVERAGE = False
 
 from circuits import Component
 from circuits.app import Daemon
 
+
 class App(Component):
 
     def __init__(self, pidfile, signalfile):
@@ -23,16 +28,19 @@ class App(Component):
         f.write(str(signal))
         f.close()
 
+
 def main():
-    _coverage = coverage(data_suffix=True)
-    _coverage.start()
+    if HAS_COVERAGE:
+        _coverage = coverage(data_suffix=True)
+        _coverage.start()
 
     pidfile = os.path.abspath(sys.argv[1])
     signalfile = os.path.abspath(sys.argv[2])
     App(pidfile, signalfile).run()
 
-    _coverage.stop()
-    _coverage.save()
+    if HAS_COVERAGE:
+        _coverage.stop()
+        _coverage.save()
 
 if __name__ == "__main__":
     main()
