@@ -4,10 +4,14 @@
 
 """Debugger Tests"""
 
+import sys
+
+import pytest
+
 try:
     from StringIO import StringIO
 except ImportError:
-    from io import StringIO
+    from io import StringIO  # NOQA
 
 from circuits import Debugger
 from circuits.core import Event, Component
@@ -16,18 +20,16 @@ from circuits.core import Event, Component
 class Test(Event):
     """Test Event"""
 
+
 class App(Component):
 
     raiseException = False
 
-    def __tick__(self):
-        if self.raiseException:
-            raise Exception()
-
     def test(self, raiseException=False):
         if raiseException:
             raise Exception()
 
+
 class Logger(object):
 
     msg = None
@@ -37,6 +39,7 @@ class Logger(object):
 
     error = debug
 
+
 def test():
     app = App()
     stderr = StringIO()
@@ -70,6 +73,7 @@ def test():
     stderr.seek(0)
     stderr.truncate()
 
+
 def test_file(tmpdir):
     logfile = str(tmpdir.ensure("debug.log"))
     stderr = open(logfile, "w+")
@@ -106,7 +110,11 @@ def test_file(tmpdir):
     stderr.seek(0)
     stderr.truncate()
 
+
 def test_filename(tmpdir):
+    if "__pypy__" in sys.modules:
+        pytest.skip("Broken on pypy")
+
     logfile = str(tmpdir.ensure("debug.log"))
     stderr = open(logfile, "r+")
 
@@ -142,6 +150,7 @@ def test_filename(tmpdir):
     stderr.seek(0)
     stderr.truncate()
 
+
 def test_exceptions():
     app = App()
     stderr = StringIO()
@@ -193,33 +202,6 @@ def test_exceptions():
     s = stderr.read().strip()
     assert s == ""
 
-def test_tick_exceptions():
-    app = App()
-    stderr = StringIO()
-    debugger = Debugger(file=stderr)
-    debugger.register(app)
-    while app:
-        app.tick()
-    stderr.seek(0)
-    stderr.truncate()
-
-    assert debugger.events
-    assert debugger.errors
-
-    app.raiseException = True
-    app.tick()
-
-    stderr.seek(0)
-    s = stderr.read().strip()
-    assert s.startswith("<Error[*.error] (<type 'exceptions.Exception'>")
-
-    stderr.seek(0)
-    stderr.truncate()
-
-    app.flush()
-    stderr.seek(0)
-    s = stderr.read().strip()
-    assert s == ""
 
 def test_IgnoreEvents():
     app = App()
@@ -255,6 +237,7 @@ def test_IgnoreEvents():
     stderr.seek(0)
     stderr.truncate()
 
+
 def test_IgnoreChannels():
     app = App()
     stderr = StringIO()
@@ -288,6 +271,7 @@ def test_IgnoreChannels():
     stderr.seek(0)
     stderr.truncate()
 
+
 def test_Logger_debug():
     app = App()
     logger = Logger()
@@ -302,6 +286,7 @@ def test_Logger_debug():
 
     assert logger.msg == repr(e)
 
+
 def test_Logger_error():
     app = App()
     logger = Logger()
@@ -314,4 +299,4 @@ def test_Logger_error():
     app.fire(e)
     app.flush()
     app.flush()
-    assert logger.msg.startswith("ERROR <listener[*.test] (App.test)> (<type \'exceptions.Exception\'>):")
+    assert logger.msg.startswith("ERROR <listener[*.test] (App.test)> (")
