@@ -4,9 +4,11 @@ import py
 
 from circuits import Event, Component
 
+
 class Test(Event):
     """Test Event"""
 
+
 class App(Component):
 
     def __init__(self):
@@ -18,23 +20,25 @@ class App(Component):
         self.handler = None
 
     def test(self):
-        return x
+        return x  # NOQA
 
-    def exception(self, etype, evalue, etraceback, handler=None):
+    def error(self, etype, evalue, etraceback, handler=None):
         self.etype = etype
         self.evalue = evalue
         self.etraceback = etraceback
         self.handler = handler
 
+
 def reraise(e):
     raise e
 
+
 def test():
     app = App()
     while app:
         app.flush()
 
-    app.push(Test())
+    app.fire(Test())
     while app:
         app.flush()
 
