@@ -15,11 +15,13 @@ import pytest
 
 from circuits import Event, Component, Manager
 
+
 class App(Component):
 
     def test(self, event, *args, **kwargs):
         pass
 
+
 class Test(Event):
     pass
 
@@ -28,12 +30,12 @@ def test():
     id = "%s:%s" % (os.getpid(), current_thread().getName())
 
     m = Manager()
-    assert repr(m) == "<Manager %s (queued=0) [S]>" % id
+    assert repr(m) == "<Manager/ %s (queued=0) [S]>" % id
 
     app = App()
     app.register(m)
     s = repr(m)
-    assert s == "<Manager %s (queued=1) [S]>" % id
+    assert s == "<Manager/ %s (queued=1) [S]>" % id
 
     m.start()
 
@@ -41,11 +43,11 @@ def test():
     sleep(0.1)
 
     s = repr(m)
-    assert s == "<Manager %s (queued=0) [R]>" % id
+    assert s == "<Manager/ %s (queued=0) [R]>" % id
 
     m.stop()
 
-    pytest.wait_for(m, "_running", False)
+    pytest.wait_for(m, "_Manager__thread", None)
 
     s = repr(m)
-    assert s == "<Manager %s (queued=0) [S]>" % id
+    assert s == "<Manager/ %s (queued=0) [S]>" % id
