@@ -1,5 +1,6 @@
 from circuits import Component
 
+
 class Client(Component):
 
     channel = "client"
@@ -13,7 +14,7 @@ class Client(Component):
         self.connected = False
         self.disconnected = False
 
-    def ready(self, component):
+    def ready(self, *args):
         self.ready = True
 
     def connected(self, host, port):
@@ -25,5 +26,10 @@ class Client(Component):
     def closed(self):
         self.closed = True
 
-    def read(self, data):
+    def read(self, *args):
+        if len(args) == 2:
+            _, data = args
+        else:
+            data = args[0]
+
         self.data = data
