@@ -28,7 +28,7 @@ class App(Component):
         self.data = []
         self.events = []
 
-    @handler(filter=True)
+    @handler(channel="*", priority=101.0)
     def event(self, event, *args, **kwargs):
         self.events.append(event)
 
@@ -91,22 +91,22 @@ def test_sourceSplit():
 def test_PASS(app):
     app.reset()
 
-    app.push(PASS("secret"))
+    app.fire(PASS("secret"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "PASS"
+    assert e.name == "command_pass"
     assert e.args[0] == "secret"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "PASS secret"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "PASS secret\r\n"
 
     data = iter(app.data)
@@ -118,25 +118,25 @@ def test_PASS(app):
 def test_USER(app):
     app.reset()
 
-    app.push(USER("foo", "localhost", "localhost", "Test Client"))
+    app.fire(USER("foo", "localhost", "localhost", "Test Client"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "USER"
+    assert e.name == "command_user"
     assert e.args[0] == "foo"
     assert e.args[1] == "localhost"
     assert e.args[2] == "localhost"
     assert e.args[3] == "Test Client"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "USER foo \"localhost\" \"localhost\" :Test Client"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "USER foo \"localhost\" \"localhost\" :Test Client\r\n"
 
     data = iter(app.data)
@@ -148,22 +148,22 @@ def test_USER(app):
 def test_NICK(app):
     app.reset()
 
-    app.push(NICK("test"))
+    app.fire(NICK("test"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "NICK"
+    assert e.name == "command_nick"
     assert e.args[0] == "test"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "NICK test"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "NICK test\r\n"
 
     data = iter(app.data)
@@ -175,22 +175,22 @@ def test_NICK(app):
 def test_PING(app):
     app.reset()
 
-    app.push(PING("localhost"))
+    app.fire(PING("localhost"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "PING"
+    assert e.name == "command_ping"
     assert e.args[0] == "localhost"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "PING :localhost"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "PING :localhost\r\n"
 
     data = iter(app.data)
@@ -202,22 +202,22 @@ def test_PING(app):
 def test_PONG(app):
     app.reset()
 
-    app.push(PONG("localhost"))
+    app.fire(PONG("localhost"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "PONG"
+    assert e.name == "command_pong"
     assert e.args[0] == "localhost"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "PONG :localhost"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "PONG :localhost\r\n"
 
     data = iter(app.data)
@@ -229,22 +229,22 @@ def test_PONG(app):
 def test_QUIT(app):
     app.reset()
 
-    app.push(QUIT())
+    app.fire(QUIT())
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "QUIT"
+    assert e.name == "command_quit"
     assert not e.args
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "QUIT :Leaving"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "QUIT :Leaving\r\n"
 
     data = iter(app.data)
@@ -254,22 +254,22 @@ def test_QUIT(app):
 
     app.reset()
 
-    app.push(QUIT("Test"))
+    app.fire(QUIT("Test"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "QUIT"
+    assert e.name == "command_quit"
     assert e.args[0] == "Test"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "QUIT :Test"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "QUIT :Test\r\n"
 
     data = iter(app.data)
@@ -281,22 +281,22 @@ def test_QUIT(app):
 def test_JOIN(app):
     app.reset()
 
-    app.push(JOIN("#test"))
+    app.fire(JOIN("#test"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "JOIN"
+    assert e.name == "command_join"
     assert e.args[0] == "#test"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "JOIN #test"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "JOIN #test\r\n"
 
     data = iter(app.data)
@@ -306,23 +306,23 @@ def test_JOIN(app):
 
     app.reset()
 
-    app.push(JOIN("#test", "secret"))
+    app.fire(JOIN("#test", "secret"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "JOIN"
+    assert e.name == "command_join"
     assert e.args[0] == "#test"
     assert e.args[1] == "secret"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "JOIN #test secret"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "JOIN #test secret\r\n"
 
     data = iter(app.data)
@@ -334,22 +334,22 @@ def test_JOIN(app):
 def test_PART(app):
     app.reset()
 
-    app.push(PART("#test"))
+    app.fire(PART("#test"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "PART"
+    assert e.name == "command_part"
     assert e.args[0] == "#test"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "PART #test :Leaving"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "PART #test :Leaving\r\n"
 
     data = iter(app.data)
@@ -359,23 +359,23 @@ def test_PART(app):
 
     app.reset()
 
-    app.push(PART("#test", "Test"))
+    app.fire(PART("#test", "Test"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "PART"
+    assert e.name == "command_part"
     assert e.args[0] == "#test"
     assert e.args[1] == "Test"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "PART #test :Test"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "PART #test :Test\r\n"
 
     data = iter(app.data)
@@ -387,23 +387,23 @@ def test_PART(app):
 def test_PRIVMSG(app):
     app.reset()
 
-    app.push(PRIVMSG("test", "Hello"))
+    app.fire(PRIVMSG("test", "Hello"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "PRIVMSG"
+    assert e.name == "command_privmsg"
     assert e.args[0] == "test"
     assert e.args[1] == "Hello"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "PRIVMSG test :Hello"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "PRIVMSG test :Hello\r\n"
 
     data = iter(app.data)
@@ -415,23 +415,23 @@ def test_PRIVMSG(app):
 def test_NOTICE(app):
     app.reset()
 
-    app.push(NOTICE("test", "Hello"))
+    app.fire(NOTICE("test", "Hello"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "NOTICE"
+    assert e.name == "command_notice"
     assert e.args[0] == "test"
     assert e.args[1] == "Hello"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "NOTICE test :Hello"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "NOTICE test :Hello\r\n"
 
     data = iter(app.data)
@@ -443,29 +443,29 @@ def test_NOTICE(app):
 def test_CTCP(app):
     app.reset()
 
-    app.push(CTCP("test", "PING", "1234567890"))
+    app.fire(CTCP("test", "PING", "1234567890"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "CTCP"
+    assert e.name == "command_ctcp"
     assert e.args[0] == "test"
     assert e.args[1] == "PING"
     assert e.args[2] == "1234567890"
 
     e = next(events)
-    assert e.name == "PRIVMSG"
+    assert e.name == "command_privmsg"
     assert e.args[0] == "test"
     assert e.args[1] == "PING 1234567890"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "PRIVMSG test :PING 1234567890"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "PRIVMSG test :PING 1234567890\r\n"
 
     data = iter(app.data)
@@ -477,29 +477,29 @@ def test_CTCP(app):
 def test_CTCPREPLY(app):
     app.reset()
 
-    app.push(CTCPREPLY("test", "PING", "1234567890"))
+    app.fire(CTCPREPLY("test", "PING", "1234567890"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "CTCPREPLY"
+    assert e.name == "command_ctcpreply"
     assert e.args[0] == "test"
     assert e.args[1] == "PING"
     assert e.args[2] == "1234567890"
 
     e = next(events)
-    assert e.name == "NOTICE"
+    assert e.name == "command_notice"
     assert e.args[0] == "test"
     assert e.args[1] == "PING 1234567890"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "NOTICE test :PING 1234567890"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "NOTICE test :PING 1234567890\r\n"
 
     data = iter(app.data)
@@ -511,23 +511,23 @@ def test_CTCPREPLY(app):
 def test_KICK(app):
     app.reset()
 
-    app.push(KICK("#test", "test"))
+    app.fire(KICK("#test", "test"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "KICK"
+    assert e.name == "command_kick"
     assert e.args[0] == "#test"
     assert e.args[1] == "test"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "KICK #test test :"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "KICK #test test :\r\n"
 
     data = iter(app.data)
@@ -537,24 +537,24 @@ def test_KICK(app):
 
     app.reset()
 
-    app.push(KICK("#test", "test", "Bye"))
+    app.fire(KICK("#test", "test", "Bye"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "KICK"
+    assert e.name == "command_kick"
     assert e.args[0] == "#test"
     assert e.args[1] == "test"
     assert e.args[2] == "Bye"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "KICK #test test :Bye"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "KICK #test test :Bye\r\n"
 
     data = iter(app.data)
@@ -566,23 +566,23 @@ def test_KICK(app):
 def test_TOPIC(app):
     app.reset()
 
-    app.push(TOPIC("#test", "Hello World!"))
+    app.fire(TOPIC("#test", "Hello World!"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "TOPIC"
+    assert e.name == "command_topic"
     assert e.args[0] == "#test"
     assert e.args[1] == "Hello World!"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "TOPIC #test :Hello World!"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "TOPIC #test :Hello World!\r\n"
 
     data = iter(app.data)
@@ -594,22 +594,22 @@ def test_TOPIC(app):
 def test_MODE(app):
     app.reset()
 
-    app.push(MODE("+i"))
+    app.fire(MODE("+i"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "MODE"
+    assert e.name == "command_mode"
     assert e.args[0] == "+i"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "MODE :+i"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "MODE :+i\r\n"
 
     data = iter(app.data)
@@ -619,23 +619,23 @@ def test_MODE(app):
 
     app.reset()
 
-    app.push(MODE("+o test", "#test"))
+    app.fire(MODE("+o test", "#test"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "MODE"
+    assert e.name == "command_mode"
     assert e.args[0] == "+o test"
     assert e.args[1] == "#test"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "MODE #test :+o test"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "MODE #test :+o test\r\n"
 
     data = iter(app.data)
@@ -647,23 +647,23 @@ def test_MODE(app):
 def test_INVITE(app):
     app.reset()
 
-    app.push(INVITE("test", "#test"))
+    app.fire(INVITE("test", "#test"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "INVITE"
+    assert e.name == "command_invite"
     assert e.args[0] == "test"
     assert e.args[1] == "#test"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "INVITE test #test"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "INVITE test #test\r\n"
 
     data = iter(app.data)
@@ -675,22 +675,22 @@ def test_INVITE(app):
 def test_NAMES(app):
     app.reset()
 
-    app.push(NAMES())
+    app.fire(NAMES())
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "NAMES"
+    assert e.name == "command_names"
     assert not e.args
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "NAMES"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "NAMES\r\n"
 
     data = iter(app.data)
@@ -700,22 +700,22 @@ def test_NAMES(app):
 
     app.reset()
 
-    app.push(NAMES("#test"))
+    app.fire(NAMES("#test"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "NAMES"
+    assert e.name == "command_names"
     assert e.args[0] == "#test"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "NAMES #test"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "NAMES #test\r\n"
 
     data = iter(app.data)
@@ -731,34 +731,34 @@ def test_NAMES(app):
 def test_ping(app):
     app.reset()
 
-    app.push(Read(b"PING :localhost\r\n"))
+    app.fire(Read(b"PING :localhost\r\n"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "Read"
+    assert e.name == "read"
     assert e.args[0] == b"PING :localhost\r\n"
 
     e = next(events)
-    assert e.name == "Line"
+    assert e.name == "line"
     assert e.args[0] == "PING :localhost"
 
     e = next(events)
-    assert e.name == "Ping"
+    assert e.name == "ping"
     assert e.args[0] == "localhost"
 
     e = next(events)
-    assert e.name == "PONG"
+    assert e.name == "command_pong"
     assert e.args[0] == "localhost"
 
     e = next(events)
-    assert e.name == "RAW"
+    assert e.name == "command_raw"
     assert e.args[0] == "PONG :localhost"
 
     e = next(events)
-    assert e.name == "Write"
+    assert e.name == "write"
     assert e.args[0] == "PONG :localhost\r\n"
 
     data = iter(app.data)
@@ -770,7 +770,7 @@ def test_ping(app):
 def test_numerics(app):
     app.reset()
 
-    app.push(Read(b":localhost 001 test " +
+    app.fire(Read(b":localhost 001 test " +
         b":Welcome to the circuits Internet Relay Chat Network test\r\n"))
     while app:
         app.flush()
@@ -778,17 +778,17 @@ def test_numerics(app):
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "Read"
+    assert e.name == "read"
     assert e.args[0] == b":localhost 001 test " \
             b":Welcome to the circuits Internet Relay Chat Network test\r\n"
 
     e = next(events)
-    assert e.name == "Line"
+    assert e.name == "line"
     assert e.args[0] == ":localhost 001 test " \
             ":Welcome to the circuits Internet Relay Chat Network test"
 
     e = next(events)
-    assert e.name == "Numeric"
+    assert e.name == "numeric"
     assert e.args[0] == "localhost"
     assert e.args[1] == "test"
     assert e.args[2] == 1
@@ -798,22 +798,22 @@ def test_numerics(app):
 
     app.reset()
 
-    app.push(Read(b":localhost 332 test #test :Hello World!\r\n"))
+    app.fire(Read(b":localhost 332 test #test :Hello World!\r\n"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "Read"
+    assert e.name == "read"
     assert e.args[0] == b":localhost 332 test #test :Hello World!\r\n"
 
     e = next(events)
-    assert e.name == "Line"
+    assert e.name == "line"
     assert e.args[0] == ":localhost 332 test #test :Hello World!"
 
     e = next(events)
-    assert e.name == "Numeric"
+    assert e.name == "numeric"
     assert e.args[0] == "localhost"
     assert e.args[1] == "test"
     assert e.args[2] == 332
@@ -824,22 +824,22 @@ def test_numerics(app):
 def test_ctcp(app):
     app.reset()
 
-    app.push(Read(b":test!foo@localhost PRIVMSG test :TIME\r\n"))
+    app.fire(Read(b":test!foo@localhost PRIVMSG test :TIME\r\n"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "Read"
+    assert e.name == "read"
     assert e.args[0] == b":test!foo@localhost PRIVMSG test :TIME\r\n"
 
     e = next(events)
-    assert e.name == "Line"
+    assert e.name == "line"
     assert e.args[0] == ":test!foo@localhost PRIVMSG test :TIME"
 
     e = next(events)
-    assert e.name == "Ctcp"
+    assert e.name == "ctcp"
     assert e.args[0] == ("test", "foo", "localhost")
     assert e.args[1] == "test"
     assert e.args[2] == "TIME"
@@ -849,22 +849,22 @@ def test_ctcp(app):
 def test_message(app):
     app.reset()
 
-    app.push(Read(b":test!foo@localhost PRIVMSG test :Hello\r\n"))
+    app.fire(Read(b":test!foo@localhost PRIVMSG test :Hello\r\n"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "Read"
+    assert e.name == "read"
     assert e.args[0] == b":test!foo@localhost PRIVMSG test :Hello\r\n"
 
     e = next(events)
-    assert e.name == "Line"
+    assert e.name == "line"
     assert e.args[0] == ":test!foo@localhost PRIVMSG test :Hello"
 
     e = next(events)
-    assert e.name == "Message"
+    assert e.name == "message"
     assert e.args[0] == ("test", "foo", "localhost")
     assert e.args[1] == "test"
     assert e.args[2] == "Hello"
@@ -873,22 +873,22 @@ def test_message(app):
 def test_notice(app):
     app.reset()
 
-    app.push(Read(b":test!foo@localhost NOTICE test :Hello\r\n"))
+    app.fire(Read(b":test!foo@localhost NOTICE test :Hello\r\n"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "Read"
+    assert e.name == "read"
     assert e.args[0] == b":test!foo@localhost NOTICE test :Hello\r\n"
 
     e = next(events)
-    assert e.name == "Line"
+    assert e.name == "line"
     assert e.args[0] == ":test!foo@localhost NOTICE test :Hello"
 
     e = next(events)
-    assert e.name == "Notice"
+    assert e.name == "notice"
     assert e.args[0] == ("test", "foo", "localhost")
     assert e.args[1] == "test"
     assert e.args[2] == "Hello"
@@ -897,22 +897,22 @@ def test_notice(app):
 def test_join(app):
     app.reset()
 
-    app.push(Read(b":test!foo@localhost JOIN #test\r\n"))
+    app.fire(Read(b":test!foo@localhost JOIN #test\r\n"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "Read"
+    assert e.name == "read"
     assert e.args[0] == b":test!foo@localhost JOIN #test\r\n"
 
     e = next(events)
-    assert e.name == "Line"
+    assert e.name == "line"
     assert e.args[0] == ":test!foo@localhost JOIN #test"
 
     e = next(events)
-    assert e.name == "Join"
+    assert e.name == "join"
     assert e.args[0] == ("test", "foo", "localhost")
     assert e.args[1] == "#test"
 
@@ -920,22 +920,22 @@ def test_join(app):
 def test_part(app):
     app.reset()
 
-    app.push(Read(b":test!foo@localhost PART #test :Leaving\r\n"))
+    app.fire(Read(b":test!foo@localhost PART #test :Leaving\r\n"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "Read"
+    assert e.name == "read"
     assert e.args[0] == b":test!foo@localhost PART #test :Leaving\r\n"
 
     e = next(events)
-    assert e.name == "Line"
+    assert e.name == "line"
     assert e.args[0] == ":test!foo@localhost PART #test :Leaving"
 
     e = next(events)
-    assert e.name == "Part"
+    assert e.name == "part"
     assert e.args[0] == ("test", "foo", "localhost")
     assert e.args[1] == "#test"
     assert e.args[2] == "Leaving"
@@ -944,22 +944,22 @@ def test_part(app):
 def test_quit(app):
     app.reset()
 
-    app.push(Read(b":test!foo@localhost QUIT :Leaving\r\n"))
+    app.fire(Read(b":test!foo@localhost QUIT :Leaving\r\n"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "Read"
+    assert e.name == "read"
     assert e.args[0] == b":test!foo@localhost QUIT :Leaving\r\n"
 
     e = next(events)
-    assert e.name == "Line"
+    assert e.name == "line"
     assert e.args[0] == ":test!foo@localhost QUIT :Leaving"
 
     e = next(events)
-    assert e.name == "Quit"
+    assert e.name == "quit"
     assert e.args[0] == ("test", "foo", "localhost")
     assert e.args[1] == "Leaving"
 
@@ -967,22 +967,22 @@ def test_quit(app):
 def test_nick(app):
     app.reset()
 
-    app.push(Read(b":test!foo@localhost NICK :test_\r\n"))
+    app.fire(Read(b":test!foo@localhost NICK :test_\r\n"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "Read"
+    assert e.name == "read"
     assert e.args[0] == b":test!foo@localhost NICK :test_\r\n"
 
     e = next(events)
-    assert e.name == "Line"
+    assert e.name == "line"
     assert e.args[0] == ":test!foo@localhost NICK :test_"
 
     e = next(events)
-    assert e.name == "Nick"
+    assert e.name == "nick"
     assert e.args[0] == ("test", "foo", "localhost")
     assert e.args[1] == "test_"
 
@@ -990,22 +990,22 @@ def test_nick(app):
 def test_mode(app):
     app.reset()
 
-    app.push(Read(b":test!foo@localhost MODE #test +o test\r\n"))
+    app.fire(Read(b":test!foo@localhost MODE #test +o test\r\n"))
     while app:
         app.flush()
 
     events = iter(app.events)
 
     e = next(events)
-    assert e.name == "Read"
+    assert e.name == "read"
     assert e.args[0] == b":test!foo@localhost MODE #test +o test\r\n"
 
     e = next(events)
-    assert e.name == "Line"
+    assert e.name == "line"
     assert e.args[0] == ":test!foo@localhost MODE #test +o test"
 
     e = next(events)
-    assert e.name == "Mode"
+    assert e.name == "mode"
     assert e.args[0] == ("test", "foo", "localhost")
     assert e.args[1] == "#test"
     assert e.args[2] == "+o test"
