@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 
 import pytest
+if pytest.PLATFORM == "win32":
+    pytest.skip("Unsupported Platform")
 
 from circuits import Manager
 from circuits.net.sockets import Pipe
@@ -9,9 +11,11 @@ from circuits.net.sockets import Close, Write
 
 from .client import Client
 
+
 def pytest_generate_tests(metafunc):
     metafunc.addcall(funcargs={"Poller": Select})
 
+
 def test_pipe(Poller):
     m = Manager() + Poller()
 
@@ -28,16 +32,16 @@ def test_pipe(Poller):
         assert pytest.wait_for(a, "ready")
         assert pytest.wait_for(b, "ready")
 
-        a.push(Write(b"foo"))
+        a.fire(Write(b"foo"))
         assert pytest.wait_for(b, "data", b"foo")
 
-        b.push(Write(b"foo"))
+        b.fire(Write(b"foo"))
         assert pytest.wait_for(a, "data", b"foo")
 
-        a.push(Close())
+        a.fire(Close())
         assert pytest.wait_for(a, "disconnected")
 
-        b.push(Close())
+        b.fire(Close())
         assert pytest.wait_for(b, "disconnected")
     finally:
         m.stop()
