@@ -8,15 +8,12 @@ from .helpers import urlencode, urlopen, Request
 class Root(Controller):
 
     def index(self, *args, **kwargs):
-        args = tuple((x.encode("utf-8") if type(x) != str else x \
-                for x in args))
+        args = tuple((x.encode("utf-8") if type(x) != str else x
+                      for x in args))
         return "{0}\n{1}".format(repr(args), repr(kwargs))
 
 
 def test(webapp):
-    from circuits import Debugger
-    Debugger().register(webapp)
-
     args = ("1", "2", "3")
     kwargs = {"data": "\x00" * 4096}
     headers = {"Expect": "100-continue"}
@@ -26,6 +23,6 @@ def test(webapp):
     req = Request(url, data, headers)
     res = urlopen(req)
 
-    data = res.read().decode('utf-8').split("\n")
-    assert data[0] == repr(args)
-    assert data[1] == repr(kwargs)
+    data = res.read().split(b"\n")
+    assert eval(data[0]) == args
+    assert eval(data[1]) == kwargs
