@@ -1,9 +1,11 @@
 #!/usr/bin/env python
 
-import urllib2
-from cookielib import CookieJar
 from circuits.web import Controller
 
+from .helpers import build_opener, HTTPCookieProcessor
+from .helpers import CookieJar
+
+
 class Root(Controller):
     def index(self):
         visited = self.cookie.get("visited")
@@ -13,14 +15,15 @@ class Root(Controller):
             self.cookie["visited"] = True
             return "Hello World!"
 
+
 def test(webapp):
     cj = CookieJar()
-    opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cj))
+    opener = build_opener(HTTPCookieProcessor(cj))
 
     f = opener.open(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
 
     f = opener.open(webapp.server.base)
     s = f.read()
-    assert s == "Hello again!"
+    assert s == b"Hello again!"
