@@ -1,7 +1,13 @@
+#!/usr/bin/env python
+
+import pytest
+if pytest.PYVER[:2] == (3, 3):
+    pytest.skip("Broken on Python 3.3")
+
 from circuits.web import Controller
 from circuits.web.tools import check_auth, digest_auth
 
-from .helpers import HTTPError, HTTPError, HTTPDigestAuthHandler
+from .helpers import HTTPError, HTTPDigestAuthHandler
 from .helpers import urlopen, build_opener, install_opener
 
 
@@ -16,6 +22,7 @@ class Root(Controller):
 
         return digest_auth(self.request, self.response, realm, users)
 
+
 def test(webapp):
     try:
         f = urlopen(webapp.server.base)
