@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 from circuits.web import Controller
-from circuits.web.exceptions import *
+from circuits.web.exceptions import Forbidden, NotFound, Redirect
 
 from .helpers import urlopen, HTTPError
 
@@ -20,11 +20,13 @@ class Root(Controller):
     def test_notfound(self):
         raise NotFound()
 
+
 def test_redirect(webapp):
     f = urlopen("%s/test_redirect" % webapp.server.base)
     s = f.read()
     assert s == b"Hello World!"
 
+
 def test_forbidden(webapp):
     try:
         urlopen("%s/test_forbidden" % webapp.server.base)
@@ -34,9 +36,10 @@ def test_forbidden(webapp):
     else:
         assert False
 
+
 def test_notfound(webapp):
     try:
-         urlopen("%s/test_notfound" % webapp.server.base)
+        urlopen("%s/test_notfound" % webapp.server.base)
     except HTTPError as e:
         assert e.code == 404
         assert e.msg == "Not Found"
