@@ -1,6 +1,6 @@
 from circuits.web import expose, Controller
 
-from .helpers import urlopen, HTTPError
+from .helpers import urlopen
 
 
 class Root(Controller):
@@ -16,6 +16,7 @@ class Root(Controller):
     def foobar(self):
         return "foobar"
 
+
 def test(webapp):
     f = urlopen(webapp.server.base)
     s = f.read()
