@@ -4,19 +4,14 @@ try:
     from gzip import decompress
 except ImportError:
     import zlib
-    decompress = zlib.decompressobj(16+zlib.MAX_WBITS).decompress
-
-try:
-    from urllib.request import Request
-except ImportError:
-    from urllib2 import Request
+    decompress = zlib.decompressobj(16+zlib.MAX_WBITS).decompress  # NOQA
 
 from circuits import handler, Component
 
 from circuits.web import Controller
 from circuits.web.tools import gzip
 
-from .helpers import build_opener
+from .helpers import build_opener, Request
 
 
 class Gzip(Component):
@@ -27,11 +22,13 @@ class Gzip(Component):
     def _on_response(self, event, *args, **kwargs):
         event[0] = gzip(event[0])
 
+
 class Root(Controller):
 
     def index(self):
         return "Hello World!"
 
+
 def test(webapp):
     gzip = Gzip()
     gzip.register(webapp)
