@@ -8,8 +8,10 @@ from .helpers import urlencode, urlopen
 class Root(Controller):
 
     def index(self, *args, **kwargs):
-        args = tuple((x.encode("utf-8") if type(x) != str else x \
-                for x in args))
+        args = tuple((
+            x.encode("utf-8") if type(x) != str else x
+            for x in args
+        ))
         return "{0}\n{1}".format(repr(args), repr(kwargs))
 
 
@@ -19,6 +21,6 @@ def test(webapp):
     url = "%s/%s" % (webapp.server.base, "/".join(args))
     data = urlencode(kwargs).encode('utf-8')
     f = urlopen(url, data)
-    data = f.read().decode('utf-8').split("\n")
-    assert data[0] == repr(args)
-    assert data[1] == repr(kwargs)
+    data = f.read().split(b"\n")
+    assert eval(data[0]) == args
+    assert eval(data[1]) == kwargs
