@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 
-from os.path import basename
+import pytest
+
+from os import path
 from socket import gaierror
 
 from circuits import Component
@@ -9,6 +11,9 @@ from circuits.web import BaseServer, Server
 
 from .helpers import urlopen, URLError
 
+CERTFILE = path.join(path.dirname(__file__), "cert.pem")
+
+
 class BaseRoot(Component):
 
     channel = "web"
@@ -57,13 +62,35 @@ def test_server():
     assert s == b"Hello World!"
 
 
+def test_secure_server():
+    pytest.importorskip("ssl")
+
+    server = Server(0, secure=True, certfile=CERTFILE)
+    Root().register(server)
+    server.start()
+
+    try:
+        f = urlopen(server.base)
+    except URLError as e:
+        if type(e[0]) is gaierror:
+            f = urlopen("http://127.0.0.1:9000")
+        else:
+            raise
+
+    s = f.read()
+    assert s == b"Hello World!"
+
+
 def test_unixserver(tmpdir):
+    if pytest.PLATFORM == "win32":
+        pytest.skip("Unsupported Platform")
+
     sockpath = tmpdir.ensure("test.sock")
     socket = str(sockpath)
     server = Server(socket)
     Root().register(server)
     server.start()
 
-    assert basename(server.host) == "test.sock"
+    assert path.basename(server.host) == "test.sock"
 
     server.stop()
