@@ -5,15 +5,17 @@ try:
     from gzip import decompress
 except ImportError:
     import zlib
-    decompress = zlib.decompressobj(16+zlib.MAX_WBITS).decompress
+    decompress = zlib.decompressobj(16+zlib.MAX_WBITS).decompress  # NOQA
 
 from circuits.web.utils import compress
 from circuits.web.utils import get_ranges
 
+
 def test_ranges():
     assert get_ranges("bytes=3-6", 8) == [(3, 7)]
     assert get_ranges("bytes=2-4,-1", 8) == [(2, 5), (7, 8)]
 
+
 def test_gzip():
     s = b"Hello World!"
     contents = BytesIO(s)
