@@ -1,21 +1,28 @@
 #!/usr/bin/env python
 
-import xmlrpclib
-from urllib2 import urlopen
+try:
+    from xmlrpc.client import ServerProxy
+except ImportError:
+    from xmlrpclib import ServerProxy  # NOQA
 
 from circuits import Component
 from circuits.web import Controller, XMLRPC
 
+from .helpers import urlopen
+
+
 class Test(Component):
 
     def eval(self, s):
         return eval(s)
 
+
 class Root(Controller):
 
     def index(self):
         return "Hello World!"
 
+
 def test(webapp):
     rpc = XMLRPC("/rpc")
     test = Test()
@@ -24,12 +31,12 @@ def test(webapp):
 
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
 
     url = "%s/rpc/" % webapp.server.base
-    xmlrpc = xmlrpclib.ServerProxy(url, allow_none=True)
+    server = ServerProxy(url, allow_none=True)
 
-    r = xmlrpc.eval("1 + 2")
+    r = server.eval("1 + 2")
     assert r == 3
 
     rpc.unregister()
